@@ -1,5 +1,5 @@
 package Text::ANSI::Fold::Util;
-our $VERSION = "1.01";
+our $VERSION = "1.02";
 
 use v5.14;
 use utf8;
@@ -32,7 +32,7 @@ Text::ANSI::Fold::Util - Text::ANSI::Fold utilities (width, substr)
 
 =head1 VERSION
 
-Version 1.01
+Version 1.02
 
 =head1 DESCRIPTION
 
@@ -44,6 +44,11 @@ functions are aware of ANSI terminal sequence.
 There are exportable functions start with B<ansi_> prefix, and
 unexportable functions without them.
 
+Unless otherwise noted, these functions are executed in the same
+context as C<ansi_fold> exported by C<Text::ANSI::Fold> module. That
+is, the parameters set by C<Text::ANSI::Fold->configure> are
+effective.
+
 =over 7
 
 =cut
@@ -89,8 +94,9 @@ sub substr {
     if ($offset < 0) {
 	$offset = max(0, $offset + ansi_width($text));
     }
-    my @s = Text::ANSI::Fold
-	->new(text => $text, width => [ $offset, $length // -1, -1 ])
+    state $fold = Text::ANSI::Fold->configure();
+    my @s = $fold
+	->configure(text => $text, width => [ $offset, $length // -1, -1 ])
 	->chops;
     if (defined $replacement) {
 	$s[0] . $replacement . ($s[2] // '');
@@ -111,13 +117,13 @@ __END__
 =head1 SEE ALSO
 
 L<Text::ANSI::Fold::Util>,
-L<https://github.com/kaz-utashiro/Text-ANSI-Fold-Util>
+L<https://github.com/tecolicom/Text-ANSI-Fold-Util>
 
 L<Text::ANSI::Tabs>,
-L<https://github.com/kaz-utashiro/Text-ANSI-Tabs>
+L<https://github.com/tecolicom/Text-ANSI-Tabs>
 
 L<Text::ANSI::Fold>,
-L<https://github.com/kaz-utashiro/Text-ANSI-Fold>
+L<https://github.com/tecolicom/Text-ANSI-Fold>
 
 L<Text::Tabs>
 
@@ -127,7 +133,7 @@ Kazumasa Utashiro
 
 =head1 LICENSE
 
-Copyright 2020-2022 Kazumasa Utashiro.
+Copyright 2020-2024 Kazumasa Utashiro.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
